<?php

namespace Drupal\acquia_search\EventSubscriber\AcquiaSubscriptionData;

use Drupal\acquia_connector\AcquiaConnectorEvents;
use Drupal\acquia_connector\Event\AcquiaSubscriptionDataEvent;
use Drupal\acquia_connector\Settings;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\SitePathFactory;
use Drupal\Core\State\State;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Add metadata from Acquia Search to Acquia Connector's subscription.
 */
class AcquiaSearchData implements EventSubscriberInterface {

  /**
   * Acquia Search Module Version.
   *
   * @var string
   */
  protected string $moduleVersion;

  /**
   * @var \Drupal\Core\State\State
   */
  protected $state;

  /**
   * Add metadata constructor
   *
   * @param \Drupal\Core\Extension\ModuleExtensionList $module_extension_list
   *   Module Extension List
   */
  public function __construct(ModuleExtensionList $module_extension_list, State $state) {
    $info = $module_extension_list->getExtensionInfo('acquia_search');
    // Send the version, or at least the core compatibility as a fallback.
    $this->moduleVersion = (string) ($info['version'] ?? \Drupal::VERSION);
    $this->state = $state;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AcquiaConnectorEvents::GET_SUBSCRIPTION][] = ['onGetSubscriptionData', 100];
    return $events;
  }

  /**
   * Gets a prebuilt Settings object from Drupal's settings file.
   *
   * @param \Drupal\acquia_connector\Event\AcquiaSubscriptionDataEvent $event
   *   The dispatched event.
   *
   * @see \Drupal\acquia_connector\Settings
   */
  public function onGetSubscriptionData(AcquiaSubscriptionDataEvent $event) {
    $config = $event->getConfig('acquia_search.settings');
    $subscription_data = $event->getData();

    $subscription_data['acquia_search'] = $config->getRawData();

    // Add the v3 Search URL to the subscription data.
    // Customers must manually set this state value to get any V3 cores.
    // The default is: 'https://api.sr.acquia.com'
    $v3_host = $this->state->get('acquia_search.v3_api_host');
    if (!empty($v3_host)) {
      $subscription_data['acquia_search']['v3']['host'] = $v3_host;
    }
    // Get the current module version of search.
    $subscription_data['acquia_search']['module_version'] = $this->moduleVersion;

    // Add Acquia Search module version to subscription data.
    $event->setData($subscription_data);
  }

}
