<?php

namespace Drupal\acquia_search\EventSubscriber\PossibleCores;

use Drupal\acquia_connector\Subscription;
use Drupal\acquia_search\AcquiaSearchEvents;
use Drupal\acquia_search\Event\AcquiaPossibleCoresEvent;
use Drupal\Core\Site\Settings;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Gets the ContentHub Server settings from Drupal's settings.
 */
class LocalOverride implements EventSubscriberInterface {

  /**
   * Drupal Settings.
   *
   * @var \Drupal\Core\Site\Settings
   */
  protected $settings;

  /**
   * Acquia subscription service.
   *
   * @var \Drupal\acquia_connector\Subscription
   */
  protected $subscription;

  /**
   * Get Possible Cores from Cloud Constructor
   *
   * @param \Drupal\Core\Site\Settings $settings
   *   Core Settings
   */
  public function __construct(Settings $settings, Subscription $subscription) {
    $this->settings = $settings;
    $this->subscription = $subscription;
  }
  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    // Overridden fires first and supersedes all other possible cores.
    $events[AcquiaSearchEvents::GET_POSSIBLE_CORES][] = ['onGetPossibleCores', 9999];
    return $events;
  }

  /**
   * Gets a preset possible core from settings.
   *
   * @param \Drupal\acquia_search\Event\AcquiaPossibleCoresEvent $event
   *   The dispatched event.
   *
   * @see \Drupal\acquia_connector\Settings
   */
  public function onGetPossibleCores(AcquiaPossibleCoresEvent $event) {
    // Never allow overridden settings on Acquia Cloud
    if ($this->subscription->getProvider() === 'acquia_cloud') {
      return;
    }

    $search_settings = $this->settings::get('acquia_search');
    if (is_array($search_settings)) {
      $core = $search_settings['override_search_core'];
      $readonly = $search_settings['read_only'] ?? TRUE;
      if (isset($core)) {
        $event->addPossibleCore($core);
        $event->setReadOnly($readonly);
        $event->stopPropagation();
      }
    }
  }

}
